@@ -3,14 +3,32 @@ vp_list_mixed <- list(example_vp, "not_a_vp")
 vpts <- example_vpts
 
 test_that("get_quantity() returns error on incorrect parameters", {
-  expect_error(get_quantity("not_a_vp", "dens"))
-  expect_error(get_quantity(vp_list_mixed, "dens"), "`x` must be list of `vp` objects.", fixed = TRUE)
-  expect_error(get_quantity(vp, "not_a_quantity"), "Can't find quantity `not_a_quantity` in `x`", fixed = TRUE)
-  expect_error(get_quantity(vpts, "not_a_quantity"), "Can't find quantity `not_a_quantity` in `x`", fixed = TRUE)
+  expect_error(
+    get_quantity("not_a_vp", "dens"),
+    regexp = "no applicable method for 'get_quantity' applied to an object of class")
+  expect_error(
+    get_quantity(vp_list_mixed, "dens"),
+    "`x` must be list of `vp` objects.",
+    fixed = TRUE
+  )
+  expect_error(
+    get_quantity(vp, "not_a_quantity"),
+    "Can't find quantity `not_a_quantity` in `x`",
+    fixed = TRUE
+  )
+  expect_error(
+    get_quantity(vpts, "not_a_quantity"),
+    "Can't find quantity `not_a_quantity` in `x`",
+    fixed = TRUE
+  )
 
   # Quantities are case sensitive
-  expect_error(get_quantity(vp, "dbzh"))
-  expect_error(get_quantity(vp, "DENS"))
+  expect_error(get_quantity(vp, "dbzh"),
+               regexp = "Can't find quantity `dbzh` in `x`.",
+               fixed = TRUE)
+  expect_error(get_quantity(vp, "DENS"),
+               regexp = "Can't find quantity `DENS` in `x`.",
+               fixed = TRUE)
 })
 
 test_that("get_quantity.vp() returns correct quantity, processing eta, dbz, ff when below sd_vvp_threshold", {
