@@ -64,11 +64,12 @@ test_that("read_cajun() returns expected data", {
   write.csv(x = cajun_csv, non_empty_file_path)
   expect_equal(
     ignore_attr = TRUE,
+    tolerance=0.0001,
     read_cajun(non_empty_file_path, wavelength = c("S"))$data,
     dplyr::tribble(
       ~height, ~u, ~v, ~w, ~ff, ~dd, ~sd_vvp, ~gap, ~dbz, ~eta, ~dens, ~DBZH, ~n, ~n_dbz, ~n_all, ~n_dbz_all, ~elev1, ~nvolumes_gr35_e1, ~elev2, ~nvolumes_gr35_e2, ~vcp, ~percent_rain,
-      1L, 9.1082, 5.4677, NA, 36.8916, 29911L, 7.2845, FALSE, 3.7747820481656, 50L, 4.54545454545455, 0.00727495214460544, NA, -6404.5974442746, NA, 851.2421, 12.5202, 0.3646, 216L, 1.3329, 0L, 852.3826,
-      2L, 14.4428, 10.1568, NA, 44.6877, 49823L, 10.2681, FALSE, 8.54599459536223, 150L, 13.6363636363636, 0.00727495214460544, NA, -241.9400975439, NA, 212.6159, 11.5492, 0.3646, 216L, 1.3329, 0L, 213.7921
+      1L, 9.1082, 5.4677, NA, 36.8916, 29911L, 7.2845, FALSE, 3.459612, 50L, 4.54545454545455, -0.3078956, NA, -6404.5974442746, NA, 851.2421, 12.5202, 0.3646, 216L, 1.3329, 0L, 852.3826,
+      2L, 14.4428, 10.1568, NA, 44.6877, 49823L, 10.2681, FALSE, 8.230824, 150L, 13.6363636363636, -0.3078956, NA, -241.9400975439, NA, 212.6159, 11.5492, 0.3646, 216L, 1.3329, 0L, 213.7921
     )
   )
 })
